"""The version number is based on semantic versioning.

References
- https://semver.org/
- https://www.python.org/dev/peps/pep-0440/

This file is autogenerated, do not modify by hand.
"""
__version__ = "1.0.0-beta.61"
COMMIT = "0c4c6894bb03ac8bc31aa2767dbbcccf9b23deb5"
MAJOR = 1
MINOR = 0
PATCH = 0
